@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.33 $
+  $Revision: 1.35 $
 
   Example code: main server code.
 
@@ -18,7 +18,7 @@
         ottrey (09/03/1999) Created.
   ******************/ /******************
   Copyright (c) 1993, 1994, 1995, 1996, 1997  The TERENA Association
-  Copyright (c) 1998, 1999, 2000, 2001            RIPE NCC
+  Copyright (c) 1998, 1999, 2000, 2001, 2002  RIPE NCC
  
   All Rights Reserved
   
@@ -102,12 +102,19 @@ void install_signal_handler()
    sigaction(SIGINT, &sig, NULL);
    sigaction(SIGTERM, &sig, NULL);
     
+   /* SIGPIPE occurs at uncomfortable times on TCP sockets, so we ignore it.
+      In such a case we still get a -1 from the offending I/O operation, and 
+      the errno of EPIPE. */
+   sig.sa_handler = SIG_IGN;
+   sigaction(SIGPIPE, &sig, NULL);
+
    /* now block the delivery of these signals in other threads */
    /* this will be inherited by other threads */
    sigemptyset(&sset);
    sigaddset(&sset, SIGTERM);
    sigaddset(&sset, SIGINT);
    sigaddset(&sset, SIGUSR1); 
+   sigaddset(&sset, SIGPIPE);
    pthread_sigmask(SIG_BLOCK, &sset, NULL);
   	
 }
