@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.33 $
+  $Revision: 1.35 $
 
   Radix tree (rx).  rx_node.c - functions to operate on nodes of the tree
   (creation/deletion).
@@ -9,7 +9,7 @@
   Design and implementation by: Marek Bukowy
 
   ******************/ /******************
-  Copyright (c) 1999,2000,2001                    RIPE NCC
+  Copyright (c) 1999,2000,2001,2002               RIPE NCC
  
   All Rights Reserved
   
@@ -664,10 +664,24 @@ RX_in_node(   rx_oper_mt mode,       /*+ MODE={cre|mod|del} +*/
   
   leafptr->iprange = *rang;
   
+#if 0  
 /* XXX */  
 if(prefcount==0) {
 	fprintf(stderr, "**** prefcount=0 range: [%s][%u-%u]\n", buf, (rang->begin).words[0], (rang->end).words[0]);
 }
+#endif
+
+  if(prefcount==0) {
+  /* XXX This indicates that some inetnum ranges are not correct (e.g. start>end) */
+  /* XXX Should not happen and may break normal operation of the rx lookups */
+  /* XXX maybe we need to die here, but this is too harsh at this point */
+      IP_rang_b2a(rang, buf, IP_RANGSTR_MAX );
+      ER_perror(FAC_RX, RX_BADKEY, "prefcount=0 range: [%s][%u-%u]\n", 
+                      buf, (rang->begin).words[0], (rang->end).words[0]);
+  }
+
+
+             
   
   for(i=0; i < prefcount; i++) {
     ip_prefix_t *mypref = g_list_nth_data(preflist, i);
