@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.36 $
+  $Revision: 1.40 $
 
   Wrapper for NRTM client
 
@@ -11,7 +11,7 @@
   Modification History:
         andrei (17/01/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000,2001                         RIPE NCC
+  Copyright (c) 2000,2001,2002                      RIPE NCC
  
   All Rights Reserved
   
@@ -39,12 +39,17 @@
 #include <arpa/inet.h>
 #include <fcntl.h>
 #include <signal.h>
+#include <sys/poll.h>
 
 
 /* here we store sockets for update threads */
 /* they are from SV module */
 extern int SV_update_sock[];
 
+/* here is the shutdown pipe for update threads */
+/* also from SV module (apologies for breaking encapsulation) */
+extern int SV_shutdown_recv_fd;
+
 /* Response time to swtching updates on and off */
 #define TIMEOUT 60 
 
@@ -109,7 +114,7 @@ int network;
    memcpy(&serv_addr.sin_addr, paddr, sizeof(struct in_addr));
 /*   fprintf(stderr,"Trying %s port %d\n", inet_ntoa(serv_addr.sin_addr), nrtm->port);*/
    if(connect(sockfd, (struct sockaddr *)&serv_addr, sizeof(serv_addr))==-1) {
-     ER_perror(FAC_UD, UD_FS, "cannot connect"); 
+     ER_perror(FAC_UD, UD_FS, "cannot connect, errno:%d", errno); 
      close(sockfd);
      return(-1);
    }  
@@ -203,6 +208,9 @@ char *source_name = ca_get_srcname(source_hdl);
    g_string_free(er_def, TRUE);
    UT_free(er_ud_def);
   }  
+
+  /* load the dictionary */
+  rpsl_load_dictionary(RPSL_DICT_CORE);
          
   nrtm=UT_calloc(1, sizeof(struct _nrtm));
   if(nrtm==NULL) {
@@ -403,6 +411,7 @@ char *db_host, *db_name, *db_user, *db_passwd;
 int db_port;
 ip_addr_t address;
 char *source_name;
+struct pollfd pfd[2];
 
    source_name = ca_get_srcname(source_hdl);  
 
@@ -426,6 +435,10 @@ char *source_name;
    UT_free(er_ud_def);
   } 
 
+  /* load the dictionary */
+    rpsl_load_dictionary(RPSL_DICT_CORE);
+    
+
 /* get mode of operation: protected/unprotected (dummy) */
   memset(&ud_stream, 0, sizeof(ud_stream));
   ud_stream.source_hdl=source_hdl;
@@ -461,6 +474,12 @@ char *source_name;
   ud_stream.num_skip=0;
   ud_stream.load_pass=0;
   ud_stream.nrtm=NULL;
+
+  /* set up poll structure */
+  pfd[0].fd = listening_socket;
+  pfd[0].events = POLLIN;
+  pfd[1].fd = SV_shutdown_recv_fd;
+  pfd[1].events = POLLIN;
  
 /*+++ main cycle +++*/
 
@@ -469,6 +488,16 @@ do { /* be alive while do_server is 1. do_server is turned off by SIGINT */
    /* make a record for thread accounting */
    TA_add(listening_socket, "update");
    TA_setactivity("waiting");
+
+   /* check for input */
+   if (poll(pfd, 2, -1) == -1) {
+        ER_perror(FAC_SV, 1, "UD_do_updates got error %d on poll; %s",
+                  errno, strerror(errno));
+        continue;
+   }
+
+   /* shutdown */
+   if (pfd[1].revents != 0) break;
  
    /* accept connection */
    connected_socket = SK_accept_connection(listening_socket);
